/* SDL Dynamic FS/Window toggling
   A Very simple and stupid example
   by Sam Hart <hart@geekcomix.com>
   Placed in the public domain, do whatever you want with it */

#include <stdio.h>
#include <SDL/SDL.h>

#define BPP 0
#define RES_X 640
#define RES_Y 400
#define SPEEDX -8
#define SPEEDY 5

/* First we need our screen surfaces */
SDL_Surface *screen;
SDL_Surface *sphere;
SDL_Surface *click_here;
Uint32 video_flags, lib_flags, black_color;

int main(void)
{
        int x, y, dx, dy, i;
        SDL_Event event;
        SDL_Rect dest;
        Uint8 *keys;

        /* We will start out Windowed */
        video_flags = (SDL_HWPALETTE | SDL_DOUBLEBUF);
        lib_flags = SDL_INIT_VIDEO;

        if(SDL_Init(lib_flags) < 0) {
                fprintf(stderr, "Couldn't initialize SDL: %s\n", SDL_GetError());
                exit(-1);
        }

        /* Load the images */
        sphere = SDL_LoadBMP("sphere.bmp");
        click_here = SDL_LoadBMP("click.bmp");

        /* Init the screen */
        screen = SDL_SetVideoMode(RES_X, RES_Y, BPP, video_flags);

        /* Get our black color */
        black_color = SDL_MapRGB(screen->format, 0, 0, 0);
        SDL_FillRect (screen, NULL, black_color);

        SDL_ShowCursor(1);
        SDL_WM_SetCaption("SDL FS/Win Toggle", "scrtog");

        /* Start out in the center of the screen -
          Note that there is no error checking here,
          we assume that sphere is smaller than RES_X & RES_Y */
        x = (RES_X - sphere->w) /2;
        y = (RES_Y - sphere->h) /2;
        dx = SPEEDX;
        dy = SPEEDY;

        /* Blit the button */
        dest.x = 0;
        dest.y = 0;
        dest.w = click_here->w;
        dest.h = click_here->h;
        SDL_BlitSurface(click_here, NULL, screen, &dest);

        /* Set up the (now constant) dest.w & h for sphere */
        dest.w = sphere->w;
        dest.h = sphere->h;

        /* Main Loop */
        while (SDL_PollEvent(&event) >= 0) {
                if(event.type & (SDL_KEYUP | SDL_KEYDOWN)) {
                        keys = SDL_GetKeyState(&i);
                        /* Press ESC to exit */
                        if(keys[SDLK_ESCAPE])
                                break;
                }
                if(event.type == SDL_QUIT) {
                        break;
                }
                if(event.type  == SDL_MOUSEBUTTONDOWN) {
                        video_flags = video_flags ^ SDL_FULLSCREEN;
                        screen = SDL_SetVideoMode(RES_X, RES_Y, BPP, video_flags);
                        dest.x = 0;
                        dest.y = 0;
                        dest.w = click_here->w;
                        dest.h = click_here->h;
                        SDL_BlitSurface(click_here, NULL, screen, &dest);

                        /* Set up the (now constant) dest.w & h for sphere */
                        dest.w = sphere->w;
                        dest.h = sphere->h;
                }
                /* Erase the sphere */
                dest.x = x;
                dest.y = y;

                SDL_FillRect(screen, &dest, black_color);

                /* Move and reblit the sphere */
                x += dx;
                y += dy;

                if(x < 0) {
                        x = 0;
                        dx *= -1;
                }
                if(y < click_here->h) {
                        y = click_here->h;
                        dy *= -1;
                }
                if(x > (RES_X - dest.w)) {
                        x = RES_X - dest.w;
                        dx *= -1;
                }
                if(y > (RES_Y - dest.h)) {
                        y = RES_Y - dest.h;
                        dy *= -1;
                }
                dest.x = x;
                dest.y = y;
                SDL_BlitSurface(sphere, NULL, screen, &dest);

                SDL_Flip(screen);
        }

        exit(0);

}